<?php

class Moceansms_WooCommerce_Notification {
	protected $log;

	public function __construct( Moceansms_WooCoommerce_Logger $log = null ) {
		if ( $log === null ) {
			$log = new Moceansms_WooCoommerce_Logger();
		}

		$this->log = $log;
	}

	public function send_sms_woocommerce_order_status_pending( $order_id ) {
		$this->send_customer_notification( $order_id, "pending" );
	}

	public function send_sms_woocommerce_order_status_failed( $order_id ) {
		$this->send_customer_notification( $order_id, "failed" );
	}

	public function send_sms_woocommerce_order_status_on_hold( $order_id ) {
		$this->send_customer_notification( $order_id, "on-hold" );
	}

	public function send_sms_woocommerce_order_status_processing( $order_id ) {
		$this->send_customer_notification( $order_id, "processing" );
	}

	public function send_sms_woocommerce_order_status_completed( $order_id ) {
		$this->send_customer_notification( $order_id, "completed" );
	}

	public function send_sms_woocommerce_order_status_refunded( $order_id ) {
		$this->send_customer_notification( $order_id, "refunded" );
	}

	public function send_sms_woocommerce_order_status_cancelled( $order_id ) {
		$this->send_customer_notification( $order_id, "cancelled" );
	}

	public function send_sms_woocommerce_order_status_changed( $order_id, $old_status, $new_status ) {
		$this->log->add( 'MoceanSMS', 'Order status changed": old status: ' . $old_status . ' , new status: ' . $new_status );
	}

	public function woocommerce_payment_complete( $order_id ) {
		$this->log->add( 'MoceanSMS', 'Payment completed' );
	}

	public function woocommerce_payment_complete_order_status( $order_id ) {
		$this->log->add( 'MoceanSMS', 'Completed order status' );
	}

	public function send_customer_notification( $order_id, $status ) {
		if ( ! in_array( $status, moceansms_get_options( 'moceansms_woocommerce_send_sms', 'customer_setting', array() ) ) ) {
			return;
		}

		$order_details = new WC_Order( $order_id );

		$message = moceansms_get_options( 'moceansms_woocommerce_sms_template_' . $status, 'customer_setting', '' );
		if ( empty( $message ) ) {
			$message = moceansms_get_options( 'moceansms_woocommerce_sms_template_default', 'customer_setting', '' );
		}
		if ( empty( $message ) ) {
			return;
		}
		$message           = $this->replace_order_keyword( $message, $order_details, 'customer', $status );
		$customer_phone_no = $this->check_and_get_phone_number( $order_details->get_billing_phone(), $order_details->get_billing_country() );

		if ( $customer_phone_no !== false ) {
			$this->log->add( 'MoceanSMS', 'Customer\'s billing phone number (' . $order_details->get_billing_phone() . ') in country (' . $order_details->get_billing_country() . ') converted to ' . $customer_phone_no );
		} else {
			$customer_phone_no = $order_details->get_billing_phone();
		}

		$this->send_sms( $customer_phone_no, $message );
	}

	public function send_admin_notification( $order_id ) {
		if ( moceansms_get_options( 'moceansms_woocommerce_admin_send_sms', 'admin_setting', 'off' ) == 'off' ) {
			return;
		}

		$order_details  = new WC_Order( $order_id );
		$message        = moceansms_get_options( 'moceansms_woocommerce_admin_sms_template', 'admin_setting', '' );
		$message        = $this->replace_order_keyword( $message, $order_details, 'admin', '' );
		$admin_phone_no = trim( moceansms_get_options( 'moceansms_woocommerce_admin_sms_recipients', 'admin_setting', '' ) );
		$admin_phone_no = $this->phone_number_processing( $admin_phone_no );
		$admin_phone_no = str_replace( ',', ' ', $admin_phone_no );
		if ( $admin_phone_no == '' || $message == '' ) {
			return;
		}
		$this->send_sms( $admin_phone_no, $message );
	}

	public function send_sms( $phone_no, $message, $medium = 'Wordpress-Woocommerce-Plugin' ) {
		require_once plugin_dir_path( __DIR__ ) . 'lib/MoceanSMS.php';

		$api_key    = moceansms_get_options( "moceansms_woocommerce_api_key", 'moceansms_setting', '' );
		$api_secret = moceansms_get_options( "moceansms_woocommerce_api_secret", 'moceansms_setting', '' );
		$sms_from   = moceansms_get_options( "moceansms_woocommerce_sms_from", 'moceansms_setting', '' );

		if ( $api_key == '' || $api_secret == '' ) {
			$this->log->add( 'MoceanSMS', "Failed sent SMS, required field empty: api_key = ($api_key), api_secret = ($api_secret)" );

			return;
		}
		if ( $sms_from == '' ) {
			$sms_from = 'SMS';
		}

		$this->log->add( 'MoceanSMS', 'Sending SMS to ' . $phone_no . ', message: ' . $message );

		try {
			$moceansms_rest = new MoceanSMS( $api_key, $api_secret );
			$rest_response  = $moceansms_rest->sendSMS( $sms_from, $phone_no, $message, $medium );

			$this->log->add( 'MoceanSMS', 'SMS response from SMS gateway: ' . $rest_response );
		} catch ( Exception $e ) {
			$this->log->add( 'MoceanSMS', 'Failed sent SMS: ' . $e->getMessage() );
		}
	}

	protected function check_and_get_phone_number( $phone_number, $country ) {
		$check_phone_number_request_url = 'https://dashboard.moceanapi.com/public/mobileChecking?mobile_number={{phone}}&country_code={{country}}';
		$response                       = wp_remote_get( str_replace(
			array( '{{phone}}', '{{country}}' ),
			array( $phone_number, $country ),
			$check_phone_number_request_url
		) );

		if ( is_array( $response ) ) {
			$customer_phone_no = wp_remote_retrieve_body( $response );
			if ( ctype_digit( $customer_phone_no ) ) {
				return $customer_phone_no;
			}

			$this->log->add( 'MoceanSMS', 'check number api err response:' . $customer_phone_no );

			return false;
		}

		$this->log->add( 'MoceanSMS', 'check number api timeout, continue send without formatting' );

		return false;
	}

	protected function replace_order_keyword( $message, $order_details, $user_type, $order_status ) {
		/** @var WC_Order $order_details */
		$items            = $order_details->get_items();
		$product_name     = '';
		$product_with_qty = '';
		foreach ( $items as $item ) {
			$product_name     .= ', ' . $item->get_name();
			$product_with_qty .= ', ' . $item->get_name() . ' X ' . $item->get_quantity();
		}
		if ( $product_name ) {
			$product_name     = substr( $product_name, 2 );
			$product_with_qty = substr( $product_with_qty, 2 );
		}

		$search  = array(
			'[shop_name]',
			'[shop_email]',
			'[shop_url]',
			'[order_id]',
			'[order_currency]',
			'[order_amount]',
			'[order_status]',
			'[order_product]',
			'[order_product_with_qty]',
			'[billing_first_name]',
			'[billing_last_name]',
			'[billing_phone]',
			'[billing_email]',
			'[billing_company]',
			'[billing_address]',
			'[billing_country]',
			'[billing_city]',
			'[billing_state]',
			'[billing_postcode]',
			'[payment_method]'
		);
		$replace = array(
			get_bloginfo( 'name' ),
			get_bloginfo( 'admin_email' ),
			get_bloginfo( 'url' ),
			$order_details->get_order_number(),
			$order_details->get_currency(),
			$order_details->get_total(),
			ucfirst( $order_details->get_status() ),
			$product_name,
			$product_with_qty,
			$order_details->get_billing_first_name(),
			$order_details->get_billing_last_name(),
			$order_details->get_billing_phone(),
			$order_details->get_billing_email(),
			$order_details->get_billing_company(),
			$order_details->get_billing_address_1(),
			$order_details->get_billing_country(),
			$order_details->get_billing_city(),
			$order_details->get_billing_state(),
			$order_details->get_billing_postcode(),
			$order_details->get_payment_method()
		);
		$message = str_replace( $search, $replace, $message );

		$additional_billing_fields_array = $this->get_additional_billing_fields();
		foreach ( $additional_billing_fields_array as $field ) {
			$post_data = get_post_meta( $order_details->get_order_number(), $field, true );
			$message   = str_replace( '[' . $field . ']', $post_data, $message );
		}

		$status_for_basc = array( 'on-hold', 'pending', 'processing' );
		if ( $user_type == 'customer' && in_array( $order_status, $status_for_basc ) && strpos( $message, '[bank_details]' ) !== false ) {
			$bank_message          = '';
			$bank_message_template = '[bank_name] - [account_name] (Acc No.: [account_number], Sort code: [sort_code], IBAN: [iban], BIC: [bic])';
			$bank_details          = new WC_Gateway_BACS();
			if ( $order_details->payment_method == 'bacs' ) {
				foreach ( $bank_details->account_details as $details ) {
					if ( $details['bank_name'] != '' && $details['account_name'] != '' && $details['account_number'] != '' ) {
						$search       = array(
							'[bank_name]',
							'[account_name]',
							'[account_number]',
							'[sort_code]',
							'[iban]',
							'[bic]'
						);
						$replace      = array(
							$details['bank_name'],
							$details['account_name'],
							$details['account_number'],
							$details['sort_code'],
							$details['iban'],
							$details['bic']
						);
						$bank_message .= ', ' . str_replace( $search, $replace, $bank_message_template );
					}
				}
				$bank_message = str_replace( ' Sort code: ,', '', $bank_message );
				$bank_message = str_replace( ' IBAN: ,', '', $bank_message );
				$bank_message = str_replace( ', BIC: )', ')', $bank_message );

				if ( $bank_message ) {
					$bank_message = 'Bank details: ' . substr( $bank_message, 2 );
				}
			}
			$message = TRIM( str_replace( '[bank_details]', $bank_message, $message ) );
		}

		return $message;
	}

	protected function phone_number_processing( $phone_no ) {
		$updated_phone_no = '';
		if ( $phone_no != '' ) {
			$phone_no_array = explode( ",", $phone_no );
			foreach ( $phone_no_array as $number ) {
				if ( $number != '' ) {
					$number           = preg_replace( "/[^0-9,.]/", "", $number );
					$updated_phone_no .= ',' . $number;
				}
			}
			$updated_phone_no = substr( $updated_phone_no, 1 );
		}

		return $updated_phone_no;
	}

	protected function get_additional_billing_fields() {
		$default_billing_fields   = array(
			'billing_first_name',
			'billing_last_name',
			'billing_company',
			'billing_address_1',
			'billing_address_2',
			'billing_city',
			'billing_state',
			'billing_country',
			'billing_postcode',
			'billing_phone',
			'billing_email'
		);
		$additional_billing_field = array();
		$billing_fields           = array_filter( get_option( 'wc_fields_billing', array() ) );
		foreach ( $billing_fields as $field_key => $field_info ) {
			if ( ! in_array( $field_key, $default_billing_fields ) && $field_info['enabled'] ) {
				array_push( $additional_billing_field, $field_key );
			}
		}

		return $additional_billing_field;
	}
}

?>
