<?php
/**
 * Created by PhpStorm.
 * User: Neoson Lam
 * Date: 2/18/2019
 * Time: 3:25 PM.
 */

class Moceansms_Multivendor_Notification extends Moceansms_WooCommerce_Notification {
	/* @var Abstract_Moceansms_Multivendor $moceansms_multivendor */
	private $moceansms_multivendor;
	private $medium;
	private $defaultHooks = array(
		'pending',
		'on-hold',
		'processing',
		'completed',
		'cancelled',
		'refunded',
		'failed'
	);

	public function __construct( $medium = 'Wordpress-Woocommerce-Multivendor-extension', $moceansms_multivendor = null, Moceansms_WooCoommerce_Logger $log = null ) {
		parent::__construct( $log );
		if ( $moceansms_multivendor === null ) {
			$moceansms_multivendor = Moceansms_Multivendor_Factory::make();
		}
		$this->moceansms_multivendor = $moceansms_multivendor;
		$this->medium                = $medium;
	}

	public function send_to_vendors( $order_id, $status ) {
		if ( moceansms_get_options( 'moceansms_multivendor_vendor_send_sms', 'multivendor_setting', 'off' ) === 'off' ) {
			return;
		}

		// check for specific hook if sms should be send
		$activatedHooks = moceansms_get_options( 'moceansms_multivendor_vendor_send_sms_on', 'multivendor_setting', $this->defaultHooks );
		if ( ! in_array( $status, $activatedHooks ) ) {
			$this->log->add( 'MoceanSMS_Multivendor', 'not sending, current hook: ["' . $status . '"] activated hooks: ' . json_encode( $activatedHooks ) );
			return;
		}

		$this->log->add( 'MoceanSMS_Multivendor', '3rd party plugin setting: ' . moceansms_get_options( 'moceansms_multivendor_selected_plugin', 'multivendor_setting', 'auto' ) );
		if ( ! $this->moceansms_multivendor ) {
			$this->log->add( 'MoceanSMS_Multivendor', 'error: no multivendor plugin detected' );

			return;
		}
		$this->log->add( 'MoceanSMS_Multivendor', 'activated plugin: ' . Moceansms_Multivendor_Factory::$activatedPlugin );

		$order_details = wc_get_order( $order_id );
		$message       = moceansms_get_options( 'moceansms_multivendor_vendor_sms_template', 'multivendor_setting', '' );

		$vendor_data_list = $this->moceansms_multivendor->get_vendor_data_list_from_order( $order_id );

		if ( ! $vendor_data_list ) {
			//not sending sms if list return false
			return;
		}

		foreach ( $vendor_data_list as $phone_number => $vendor_datas ) {
			//format phone number
			$phone_number = $this->phone_number_processing( $phone_number );
			//replace keywords
			$this->log->add( 'MoceanSMS', 'Original template: ' . $message );
			$processed_msg = $this->replace_vendor_order_keyword( $message, $order_details, $vendor_datas );
			//send sms
			$this->send_sms( $phone_number, $processed_msg, $this->medium );
		}
	}

	public function replace_vendor_order_keyword( $message, WC_Order $order_details, $vendor_datas ) {
		$search  = array(
			'[shop_name]',
			'[shop_email]',
			'[shop_url]',
			'[vendor_shop_name]',
			'[order_id]',
			'[order_currency]',
			'[order_amount]',
			'[order_status]',
			'[order_product]',
			'[order_product_with_qty]',
			'[billing_first_name]',
			'[billing_last_name]',
			'[billing_phone]',
			'[billing_email]',
			'[billing_company]',
			'[billing_address]',
			'[billing_country]',
			'[billing_city]',
			'[billing_state]',
			'[billing_postcode]',
			'[payment_method]'
		);
		$replace = array(
			get_bloginfo( 'name' ),
			get_bloginfo( 'admin_email' ),
			get_bloginfo( 'url' ),
			$this->moceansms_multivendor->get_vendor_shop_name_from_vendor_data( $vendor_datas ),
			$order_details->get_order_number(),
			$order_details->get_currency(),
			$vendor_datas['total_amount_for_vendor'],
			ucfirst( $order_details->get_status() ),
			$vendor_datas['item'],
			$vendor_datas['product_with_qty'],
			$order_details->get_billing_first_name(),
			$order_details->get_billing_last_name(),
			$order_details->get_billing_phone(),
			$order_details->get_billing_email(),
			$order_details->get_billing_company(),
			$order_details->get_billing_address_1(),
			$order_details->get_billing_country(),
			$order_details->get_billing_city(),
			$order_details->get_billing_state(),
			$order_details->get_billing_postcode(),
			$order_details->get_payment_method()
		);
		$message = str_replace( $search, $replace, $message, $total_replaced );

		$this->log->add( 'MoceanSMS', "Total replaced keyword: $total_replaced" );

		return $message;
	}
}
